# Generated by Django 4.1.7 on 2023-03-29 14:58

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("orgs", "0031_alter_orgbackend_index_together"),
        ("dashblocks", "0010_alter_dashblock_created_by_and_more"),
    ]

    operations = [
        migrations.AlterIndexTogether(
            name="dashblock",
            index_together={("org", "is_active", "dashblock_type", "priority")},
        ),
        migrations.AlterIndexTogether(
            name="dashblocktype",
            index_together={("slug", "name")},
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-29 13:57

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("orgs", "0030_alter_invitation_created_by_and_more"),
    ]

    operations = [
        migrations.AlterIndexTogether(
            name="orgbackend",
            index_together={("org", "is_active", "slug")},
        ),
    ]
